# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.id3_tag import Id3Tag
from bitmovin_api_sdk.models.id3_tag_position_mode import Id3TagPositionMode
import pprint
import six


class FrameIdId3Tag(Id3Tag):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 position_mode=None,
                 frame=None,
                 time=None,
                 bytes_=None,
                 frame_id=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, Id3TagPositionMode, int, float, string_types, string_types) -> None
        super(FrameIdId3Tag, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, position_mode=position_mode, frame=frame, time=time)

        self._bytes = None
        self._frame_id = None
        self.discriminator = None

        if bytes_ is not None:
            self.bytes = bytes_
        if frame_id is not None:
            self.frame_id = frame_id

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(FrameIdId3Tag, self), 'openapi_types'):
            types = getattr(super(FrameIdId3Tag, self), 'openapi_types')

        types.update({
            'bytes': 'string_types',
            'frame_id': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(FrameIdId3Tag, self), 'attribute_map'):
            attributes = getattr(super(FrameIdId3Tag, self), 'attribute_map')

        attributes.update({
            'bytes': 'bytes',
            'frame_id': 'frameId'
        })
        return attributes

    @property
    def bytes(self):
        # type: () -> string_types
        """Gets the bytes of this FrameIdId3Tag.

        Base64 Encoded Data (required)

        :return: The bytes of this FrameIdId3Tag.
        :rtype: string_types
        """
        return self._bytes

    @bytes.setter
    def bytes(self, bytes_):
        # type: (string_types) -> None
        """Sets the bytes of this FrameIdId3Tag.

        Base64 Encoded Data (required)

        :param bytes_: The bytes of this FrameIdId3Tag.
        :type: string_types
        """

        if bytes_ is not None:
            if not isinstance(bytes_, string_types):
                raise TypeError("Invalid type for `bytes`, type has to be `string_types`")

        self._bytes = bytes_

    @property
    def frame_id(self):
        # type: () -> string_types
        """Gets the frame_id of this FrameIdId3Tag.

        4 character long Frame ID (required)

        :return: The frame_id of this FrameIdId3Tag.
        :rtype: string_types
        """
        return self._frame_id

    @frame_id.setter
    def frame_id(self, frame_id):
        # type: (string_types) -> None
        """Sets the frame_id of this FrameIdId3Tag.

        4 character long Frame ID (required)

        :param frame_id: The frame_id of this FrameIdId3Tag.
        :type: string_types
        """

        if frame_id is not None:
            if not isinstance(frame_id, string_types):
                raise TypeError("Invalid type for `frame_id`, type has to be `string_types`")

        self._frame_id = frame_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(FrameIdId3Tag, self), "to_dict"):
            result = super(FrameIdId3Tag, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FrameIdId3Tag):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.object_detection_timestamp_result import ObjectDetectionTimestampResult
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.machine_learning.object_detection.results.by_timestamp.object_detection_timestamp_result_list_query_params import ObjectDetectionTimestampResultListQueryParams


class ByTimestampApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ByTimestampApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, encoding_id, object_detection_id, query_params=None, **kwargs):
        # type: (string_types, string_types, ObjectDetectionTimestampResultListQueryParams, dict) -> ObjectDetectionTimestampResult
        """List object detection results grouped by timestamp

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :param object_detection_id: Id of the object detection configuration
        :type object_detection_id: string_types, required
        :param query_params: Query parameters
        :type query_params: ObjectDetectionTimestampResultListQueryParams
        :return: List of object detection results
        :rtype: ObjectDetectionTimestampResult
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/machine-learning/object-detection/{object_detection_id}/results/by-timestamp',
            path_params={'encoding_id': encoding_id, 'object_detection_id': object_detection_id},
            query_params=query_params,
            pagination_response=True,
            type=ObjectDetectionTimestampResult,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.encoding_mode import EncodingMode
from bitmovin_api_sdk.models.manifest_generator import ManifestGenerator
from bitmovin_api_sdk.models.per_title import PerTitle
from bitmovin_api_sdk.models.scheduling import Scheduling
from bitmovin_api_sdk.models.trimming import Trimming
from bitmovin_api_sdk.models.tweaks import Tweaks
import pprint
import six


class StartEncodingRequest(object):
    @poscheck_model
    def __init__(self,
                 trimming=None,
                 scheduling=None,
                 tweaks=None,
                 handle_variable_input_fps=None,
                 encoding_mode=None,
                 preview_dash_manifests=None,
                 preview_hls_manifests=None,
                 vod_dash_manifests=None,
                 vod_hls_manifests=None,
                 vod_smooth_manifests=None,
                 manifest_generator=None,
                 per_title=None):
        # type: (Trimming, Scheduling, Tweaks, bool, EncodingMode, list[ManifestResource], list[ManifestResource], list[ManifestResource], list[ManifestResource], list[ManifestResource], ManifestGenerator, PerTitle) -> None

        self._trimming = None
        self._scheduling = None
        self._tweaks = None
        self._handle_variable_input_fps = None
        self._encoding_mode = None
        self._preview_dash_manifests = list()
        self._preview_hls_manifests = list()
        self._vod_dash_manifests = list()
        self._vod_hls_manifests = list()
        self._vod_smooth_manifests = list()
        self._manifest_generator = None
        self._per_title = None
        self.discriminator = None

        if trimming is not None:
            self.trimming = trimming
        if scheduling is not None:
            self.scheduling = scheduling
        if tweaks is not None:
            self.tweaks = tweaks
        if handle_variable_input_fps is not None:
            self.handle_variable_input_fps = handle_variable_input_fps
        if encoding_mode is not None:
            self.encoding_mode = encoding_mode
        if preview_dash_manifests is not None:
            self.preview_dash_manifests = preview_dash_manifests
        if preview_hls_manifests is not None:
            self.preview_hls_manifests = preview_hls_manifests
        if vod_dash_manifests is not None:
            self.vod_dash_manifests = vod_dash_manifests
        if vod_hls_manifests is not None:
            self.vod_hls_manifests = vod_hls_manifests
        if vod_smooth_manifests is not None:
            self.vod_smooth_manifests = vod_smooth_manifests
        if manifest_generator is not None:
            self.manifest_generator = manifest_generator
        if per_title is not None:
            self.per_title = per_title

    @property
    def openapi_types(self):
        types = {
            'trimming': 'Trimming',
            'scheduling': 'Scheduling',
            'tweaks': 'Tweaks',
            'handle_variable_input_fps': 'bool',
            'encoding_mode': 'EncodingMode',
            'preview_dash_manifests': 'list[ManifestResource]',
            'preview_hls_manifests': 'list[ManifestResource]',
            'vod_dash_manifests': 'list[ManifestResource]',
            'vod_hls_manifests': 'list[ManifestResource]',
            'vod_smooth_manifests': 'list[ManifestResource]',
            'manifest_generator': 'ManifestGenerator',
            'per_title': 'PerTitle'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'trimming': 'trimming',
            'scheduling': 'scheduling',
            'tweaks': 'tweaks',
            'handle_variable_input_fps': 'handleVariableInputFps',
            'encoding_mode': 'encodingMode',
            'preview_dash_manifests': 'previewDashManifests',
            'preview_hls_manifests': 'previewHlsManifests',
            'vod_dash_manifests': 'vodDashManifests',
            'vod_hls_manifests': 'vodHlsManifests',
            'vod_smooth_manifests': 'vodSmoothManifests',
            'manifest_generator': 'manifestGenerator',
            'per_title': 'perTitle'
        }
        return attributes

    @property
    def trimming(self):
        # type: () -> Trimming
        """Gets the trimming of this StartEncodingRequest.

        Allows to encode only part of the input. Defines start (offset) and duration of the desired section.

        :return: The trimming of this StartEncodingRequest.
        :rtype: Trimming
        """
        return self._trimming

    @trimming.setter
    def trimming(self, trimming):
        # type: (Trimming) -> None
        """Sets the trimming of this StartEncodingRequest.

        Allows to encode only part of the input. Defines start (offset) and duration of the desired section.

        :param trimming: The trimming of this StartEncodingRequest.
        :type: Trimming
        """

        if trimming is not None:
            if not isinstance(trimming, Trimming):
                raise TypeError("Invalid type for `trimming`, type has to be `Trimming`")

        self._trimming = trimming

    @property
    def scheduling(self):
        # type: () -> Scheduling
        """Gets the scheduling of this StartEncodingRequest.

        Set scheduling parameters of the encoding.

        :return: The scheduling of this StartEncodingRequest.
        :rtype: Scheduling
        """
        return self._scheduling

    @scheduling.setter
    def scheduling(self, scheduling):
        # type: (Scheduling) -> None
        """Sets the scheduling of this StartEncodingRequest.

        Set scheduling parameters of the encoding.

        :param scheduling: The scheduling of this StartEncodingRequest.
        :type: Scheduling
        """

        if scheduling is not None:
            if not isinstance(scheduling, Scheduling):
                raise TypeError("Invalid type for `scheduling`, type has to be `Scheduling`")

        self._scheduling = scheduling

    @property
    def tweaks(self):
        # type: () -> Tweaks
        """Gets the tweaks of this StartEncodingRequest.

        Set special tweaks for your encoding job.

        :return: The tweaks of this StartEncodingRequest.
        :rtype: Tweaks
        """
        return self._tweaks

    @tweaks.setter
    def tweaks(self, tweaks):
        # type: (Tweaks) -> None
        """Sets the tweaks of this StartEncodingRequest.

        Set special tweaks for your encoding job.

        :param tweaks: The tweaks of this StartEncodingRequest.
        :type: Tweaks
        """

        if tweaks is not None:
            if not isinstance(tweaks, Tweaks):
                raise TypeError("Invalid type for `tweaks`, type has to be `Tweaks`")

        self._tweaks = tweaks

    @property
    def handle_variable_input_fps(self):
        # type: () -> bool
        """Gets the handle_variable_input_fps of this StartEncodingRequest.

        Enable frame dropping/duplication to handle variable frames per seconds of video input streams

        :return: The handle_variable_input_fps of this StartEncodingRequest.
        :rtype: bool
        """
        return self._handle_variable_input_fps

    @handle_variable_input_fps.setter
    def handle_variable_input_fps(self, handle_variable_input_fps):
        # type: (bool) -> None
        """Sets the handle_variable_input_fps of this StartEncodingRequest.

        Enable frame dropping/duplication to handle variable frames per seconds of video input streams

        :param handle_variable_input_fps: The handle_variable_input_fps of this StartEncodingRequest.
        :type: bool
        """

        if handle_variable_input_fps is not None:
            if not isinstance(handle_variable_input_fps, bool):
                raise TypeError("Invalid type for `handle_variable_input_fps`, type has to be `bool`")

        self._handle_variable_input_fps = handle_variable_input_fps

    @property
    def encoding_mode(self):
        # type: () -> EncodingMode
        """Gets the encoding_mode of this StartEncodingRequest.

        The pass mode of the encoding

        :return: The encoding_mode of this StartEncodingRequest.
        :rtype: EncodingMode
        """
        return self._encoding_mode

    @encoding_mode.setter
    def encoding_mode(self, encoding_mode):
        # type: (EncodingMode) -> None
        """Sets the encoding_mode of this StartEncodingRequest.

        The pass mode of the encoding

        :param encoding_mode: The encoding_mode of this StartEncodingRequest.
        :type: EncodingMode
        """

        if encoding_mode is not None:
            if not isinstance(encoding_mode, EncodingMode):
                raise TypeError("Invalid type for `encoding_mode`, type has to be `EncodingMode`")

        self._encoding_mode = encoding_mode

    @property
    def preview_dash_manifests(self):
        # type: () -> list[ManifestResource]
        """Gets the preview_dash_manifests of this StartEncodingRequest.

        List of preview DASH manifests to be created

        :return: The preview_dash_manifests of this StartEncodingRequest.
        :rtype: list[ManifestResource]
        """
        return self._preview_dash_manifests

    @preview_dash_manifests.setter
    def preview_dash_manifests(self, preview_dash_manifests):
        # type: (list) -> None
        """Sets the preview_dash_manifests of this StartEncodingRequest.

        List of preview DASH manifests to be created

        :param preview_dash_manifests: The preview_dash_manifests of this StartEncodingRequest.
        :type: list[ManifestResource]
        """

        if preview_dash_manifests is not None:
            if not isinstance(preview_dash_manifests, list):
                raise TypeError("Invalid type for `preview_dash_manifests`, type has to be `list[ManifestResource]`")

        self._preview_dash_manifests = preview_dash_manifests

    @property
    def preview_hls_manifests(self):
        # type: () -> list[ManifestResource]
        """Gets the preview_hls_manifests of this StartEncodingRequest.

        List of preview HLS manifests to be created

        :return: The preview_hls_manifests of this StartEncodingRequest.
        :rtype: list[ManifestResource]
        """
        return self._preview_hls_manifests

    @preview_hls_manifests.setter
    def preview_hls_manifests(self, preview_hls_manifests):
        # type: (list) -> None
        """Sets the preview_hls_manifests of this StartEncodingRequest.

        List of preview HLS manifests to be created

        :param preview_hls_manifests: The preview_hls_manifests of this StartEncodingRequest.
        :type: list[ManifestResource]
        """

        if preview_hls_manifests is not None:
            if not isinstance(preview_hls_manifests, list):
                raise TypeError("Invalid type for `preview_hls_manifests`, type has to be `list[ManifestResource]`")

        self._preview_hls_manifests = preview_hls_manifests

    @property
    def vod_dash_manifests(self):
        # type: () -> list[ManifestResource]
        """Gets the vod_dash_manifests of this StartEncodingRequest.

        List of VoD DASH manifests to be created after encoding finished successfully

        :return: The vod_dash_manifests of this StartEncodingRequest.
        :rtype: list[ManifestResource]
        """
        return self._vod_dash_manifests

    @vod_dash_manifests.setter
    def vod_dash_manifests(self, vod_dash_manifests):
        # type: (list) -> None
        """Sets the vod_dash_manifests of this StartEncodingRequest.

        List of VoD DASH manifests to be created after encoding finished successfully

        :param vod_dash_manifests: The vod_dash_manifests of this StartEncodingRequest.
        :type: list[ManifestResource]
        """

        if vod_dash_manifests is not None:
            if not isinstance(vod_dash_manifests, list):
                raise TypeError("Invalid type for `vod_dash_manifests`, type has to be `list[ManifestResource]`")

        self._vod_dash_manifests = vod_dash_manifests

    @property
    def vod_hls_manifests(self):
        # type: () -> list[ManifestResource]
        """Gets the vod_hls_manifests of this StartEncodingRequest.

        List of VoD HLS manifests to be created after encoding finished successfully

        :return: The vod_hls_manifests of this StartEncodingRequest.
        :rtype: list[ManifestResource]
        """
        return self._vod_hls_manifests

    @vod_hls_manifests.setter
    def vod_hls_manifests(self, vod_hls_manifests):
        # type: (list) -> None
        """Sets the vod_hls_manifests of this StartEncodingRequest.

        List of VoD HLS manifests to be created after encoding finished successfully

        :param vod_hls_manifests: The vod_hls_manifests of this StartEncodingRequest.
        :type: list[ManifestResource]
        """

        if vod_hls_manifests is not None:
            if not isinstance(vod_hls_manifests, list):
                raise TypeError("Invalid type for `vod_hls_manifests`, type has to be `list[ManifestResource]`")

        self._vod_hls_manifests = vod_hls_manifests

    @property
    def vod_smooth_manifests(self):
        # type: () -> list[ManifestResource]
        """Gets the vod_smooth_manifests of this StartEncodingRequest.

        List of VoD SMOOTH manifests to be created after encoding finished successfully

        :return: The vod_smooth_manifests of this StartEncodingRequest.
        :rtype: list[ManifestResource]
        """
        return self._vod_smooth_manifests

    @vod_smooth_manifests.setter
    def vod_smooth_manifests(self, vod_smooth_manifests):
        # type: (list) -> None
        """Sets the vod_smooth_manifests of this StartEncodingRequest.

        List of VoD SMOOTH manifests to be created after encoding finished successfully

        :param vod_smooth_manifests: The vod_smooth_manifests of this StartEncodingRequest.
        :type: list[ManifestResource]
        """

        if vod_smooth_manifests is not None:
            if not isinstance(vod_smooth_manifests, list):
                raise TypeError("Invalid type for `vod_smooth_manifests`, type has to be `list[ManifestResource]`")

        self._vod_smooth_manifests = vod_smooth_manifests

    @property
    def manifest_generator(self):
        # type: () -> ManifestGenerator
        """Gets the manifest_generator of this StartEncodingRequest.

        Sets the version of the manifest generation engine

        :return: The manifest_generator of this StartEncodingRequest.
        :rtype: ManifestGenerator
        """
        return self._manifest_generator

    @manifest_generator.setter
    def manifest_generator(self, manifest_generator):
        # type: (ManifestGenerator) -> None
        """Sets the manifest_generator of this StartEncodingRequest.

        Sets the version of the manifest generation engine

        :param manifest_generator: The manifest_generator of this StartEncodingRequest.
        :type: ManifestGenerator
        """

        if manifest_generator is not None:
            if not isinstance(manifest_generator, ManifestGenerator):
                raise TypeError("Invalid type for `manifest_generator`, type has to be `ManifestGenerator`")

        self._manifest_generator = manifest_generator

    @property
    def per_title(self):
        # type: () -> PerTitle
        """Gets the per_title of this StartEncodingRequest.

        Per-Title settings

        :return: The per_title of this StartEncodingRequest.
        :rtype: PerTitle
        """
        return self._per_title

    @per_title.setter
    def per_title(self, per_title):
        # type: (PerTitle) -> None
        """Sets the per_title of this StartEncodingRequest.

        Per-Title settings

        :param per_title: The per_title of this StartEncodingRequest.
        :type: PerTitle
        """

        if per_title is not None:
            if not isinstance(per_title, PerTitle):
                raise TypeError("Invalid type for `per_title`, type has to be `PerTitle`")

        self._per_title = per_title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StartEncodingRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.inputs.udp_multicast.udp_multicast_api import UdpMulticastApi
from bitmovin_api_sdk.encoding.inputs.udp_multicast.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.udp_multicast.udp_multicast_input_list_query_params import UdpMulticastInputListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.chunked_text_muxing import ChunkedTextMuxing
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.muxings.chunked_text.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.chunked_text.chunked_text_muxing_list_query_params import ChunkedTextMuxingListQueryParams


class ChunkedTextApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ChunkedTextApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, chunked_text_muxing, **kwargs):
        # type: (string_types, ChunkedTextMuxing, dict) -> ChunkedTextMuxing
        """Add Chunked Text muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param chunked_text_muxing: The Chunked Text muxing to be created
        :type chunked_text_muxing: ChunkedTextMuxing, required
        :return: Chunked Text muxing
        :rtype: ChunkedTextMuxing
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/muxings/chunked-text',
            chunked_text_muxing,
            path_params={'encoding_id': encoding_id},
            type=ChunkedTextMuxing,
            **kwargs
        )

    def delete(self, encoding_id, muxing_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete Chunked Text muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the Chunked Text muxing
        :type muxing_id: string_types, required
        :return: Id of the Chunked Text muxing
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/muxings/chunked-text/{muxing_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, muxing_id, **kwargs):
        # type: (string_types, string_types, dict) -> ChunkedTextMuxing
        """Chunked Text muxing details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the Chunked Text muxing
        :type muxing_id: string_types, required
        :return: Chunked Text muxing
        :rtype: ChunkedTextMuxing
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/chunked-text/{muxing_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            type=ChunkedTextMuxing,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, ChunkedTextMuxingListQueryParams, dict) -> ChunkedTextMuxing
        """List Chunked Text muxings

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: ChunkedTextMuxingListQueryParams
        :return: List of Chunked Text muxings
        :rtype: ChunkedTextMuxing
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/chunked-text',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=ChunkedTextMuxing,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.aac_channel_layout import AacChannelLayout
from bitmovin_api_sdk.models.audio_configuration import AudioConfiguration
from bitmovin_api_sdk.models.he_aac_v1_signaling import HeAacV1Signaling
import pprint
import six


class HeAacV1AudioConfiguration(AudioConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 bitrate=None,
                 rate=None,
                 channel_layout=None,
                 signaling=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, float, AacChannelLayout, HeAacV1Signaling) -> None
        super(HeAacV1AudioConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, bitrate=bitrate, rate=rate)

        self._channel_layout = None
        self._signaling = None
        self.discriminator = None

        if channel_layout is not None:
            self.channel_layout = channel_layout
        if signaling is not None:
            self.signaling = signaling

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(HeAacV1AudioConfiguration, self), 'openapi_types'):
            types = getattr(super(HeAacV1AudioConfiguration, self), 'openapi_types')

        types.update({
            'channel_layout': 'AacChannelLayout',
            'signaling': 'HeAacV1Signaling'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(HeAacV1AudioConfiguration, self), 'attribute_map'):
            attributes = getattr(super(HeAacV1AudioConfiguration, self), 'attribute_map')

        attributes.update({
            'channel_layout': 'channelLayout',
            'signaling': 'signaling'
        })
        return attributes

    @property
    def channel_layout(self):
        # type: () -> AacChannelLayout
        """Gets the channel_layout of this HeAacV1AudioConfiguration.

        Channel layout of the audio codec configuration

        :return: The channel_layout of this HeAacV1AudioConfiguration.
        :rtype: AacChannelLayout
        """
        return self._channel_layout

    @channel_layout.setter
    def channel_layout(self, channel_layout):
        # type: (AacChannelLayout) -> None
        """Sets the channel_layout of this HeAacV1AudioConfiguration.

        Channel layout of the audio codec configuration

        :param channel_layout: The channel_layout of this HeAacV1AudioConfiguration.
        :type: AacChannelLayout
        """

        if channel_layout is not None:
            if not isinstance(channel_layout, AacChannelLayout):
                raise TypeError("Invalid type for `channel_layout`, type has to be `AacChannelLayout`")

        self._channel_layout = channel_layout

    @property
    def signaling(self):
        # type: () -> HeAacV1Signaling
        """Gets the signaling of this HeAacV1AudioConfiguration.

        Sets the Spectral Band Replication (SBR) and Parameteric Stereo (PS) signaling style.

        :return: The signaling of this HeAacV1AudioConfiguration.
        :rtype: HeAacV1Signaling
        """
        return self._signaling

    @signaling.setter
    def signaling(self, signaling):
        # type: (HeAacV1Signaling) -> None
        """Sets the signaling of this HeAacV1AudioConfiguration.

        Sets the Spectral Band Replication (SBR) and Parameteric Stereo (PS) signaling style.

        :param signaling: The signaling of this HeAacV1AudioConfiguration.
        :type: HeAacV1Signaling
        """

        if signaling is not None:
            if not isinstance(signaling, HeAacV1Signaling):
                raise TypeError("Invalid type for `signaling`, type has to be `HeAacV1Signaling`")

        self._signaling = signaling

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(HeAacV1AudioConfiguration, self), "to_dict"):
            result = super(HeAacV1AudioConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HeAacV1AudioConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
